==> caosadvancedtools-0.6.0.tar.gz: caosadvancedtools-0.6.0/README.md <==
# README

## Welcome

This is the **CaosDB Advanced User Tools** repository and a part of the
CaosDB project.
This project contains tools that are beyond the typical use of
the CaosDB python client. Especially, this includes the crawler which will
typically be used by a data curator.

## Setup

Please read the [README_SETUP.md](README_SETUP.md) for instructions on how to
setup this code.

## Further Reading

Please refer to the [official
documentation](https://docs.indiscale.com/caosdb-advanced-user-tools/) for more
information.

## Contributing

Thank you very much to all contributers—[past,
present](https://gitlab.com/caosdb/caosdb/-/blob/dev/HUMANS.md), and prospective
ones.

### Code of Conduct

By participating, you are expected to uphold our [Code of
Conduct](https://gitlab.com/caosdb/caosdb/-/blob/dev/CODE_OF_CONDUCT.md).

### How to Contribute

- You found a bug, have a question, or want to request a feature? Please [create
  an issue](https://gitlab.com/caosdb/caosdb-advanced-user-tools/-/issues).
- You want to contribute code? Please fork the repository and create a merge
  request in GitLab and choose this repository as target. Make sure to select
  "Allow commits from members who can merge the target branch" under
  Contribution when creating the merge request. This allows our team to work
  with you on your request.
- If you have a suggestion for the
  [documentation](https://docs.indiscale.com/caosdb-advanced-user-tools/), the
  preferred way is also a merge request as describe above (the documentation
  resides in `src/doc`). However, you can also create an issue for it.
- You can also contact us at **info (AT) caosdb.de** and join the CaosDB
  community on
  [#caosdb:matrix.org](https://matrix.to/#/!unwwlTfOznjEnMMXxf:matrix.org).

## License

* Copyright (C) 2018 Research Group Biomedical Physics, Max Planck Institute
  for Dynamics and Self-Organization Göttingen.
* Copyright (C) 2020-2021 Indiscale GmbH <info@indiscale.com>

All files in this repository are licensed under a [GNU Affero General Public
License](LICENCE.md) (version 3 or later).

==> caosadvancedtools-0.6.1.tar.gz: caosadvancedtools-0.6.1/README.md <==
# README

## Welcome

This is the **CaosDB Advanced User Tools** repository and a part of the
CaosDB project.
This project contains tools that are beyond the typical use of
the CaosDB python client. Especially, this includes the crawler which will
typically be used by a data curator.

## Setup

Please read the [README_SETUP.md](README_SETUP.md) for instructions on how to
setup this code.

## Further Reading

Please refer to the [official
documentation](https://docs.indiscale.com/caosdb-advanced-user-tools/) for more
information.

## Contributing

Thank you very much to all contributers—[past,
present](https://gitlab.com/caosdb/caosdb/-/blob/dev/HUMANS.md), and prospective
ones.

### Code of Conduct

By participating, you are expected to uphold our [Code of
Conduct](https://gitlab.com/caosdb/caosdb/-/blob/dev/CODE_OF_CONDUCT.md).

### How to Contribute

- You found a bug, have a question, or want to request a feature? Please [create
  an issue](https://gitlab.com/caosdb/caosdb-advanced-user-tools/-/issues).
- You want to contribute code? Please fork the repository and create a merge
  request in GitLab and choose this repository as target. Make sure to select
  "Allow commits from members who can merge the target branch" under
  Contribution when creating the merge request. This allows our team to work
  with you on your request.
- If you have a suggestion for the
  [documentation](https://docs.indiscale.com/caosdb-advanced-user-tools/), the
  preferred way is also a merge request as describe above (the documentation
  resides in `src/doc`). However, you can also create an issue for it.
- You can also contact us at **info (AT) caosdb.org** and join the CaosDB
  community on
  [#caosdb:matrix.org](https://matrix.to/#/!unwwlTfOznjEnMMXxf:matrix.org).

## License

* Copyright (C) 2018 Research Group Biomedical Physics, Max Planck Institute
  for Dynamics and Self-Organization Göttingen.
* Copyright (C) 2020-2021 Indiscale GmbH <info@indiscale.com>

All files in this repository are licensed under a [GNU Affero General Public
License](LICENCE.md) (version 3 or later).
